/*
 COPYRIGHT 2010 ESRI
 
 TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
 Unpublished material - all rights reserved under the
 Copyright Laws of the United States and applicable international
 laws, treaties, and conventions.
 
 For additional information, contact:
 Environmental Systems Research Institute, Inc.
 Attn: Contracts and Legal Services Department
 380 New York Street
 Redlands, California, 92373
 USA
 
 email: contracts@esri.com
 */

@class AGSCredential;
@class AGSDynamicLayer;
@class AGSSpatialReference;
@class AGSEnvelope;
@class AGSRequestOperation;
@protocol AGSSecuredResource;

/** @file AGSGPResultLayer.h */ //Required for Globals API doc

/** @brief A dynamic layer returned from a gp task.
 
 This dynamic layer is returned as a result of calling <code>queryResultImageLayer</code> from 
 an asynchronous geoprocessing task that is associated with a result map service.
 
 @define{AGSGPResultLayer.h, ArcGIS}
 @since 1.0
 */
@interface AGSGPResultLayer : AGSDynamicLayer <AGSCoding, AGSSecuredResource>

/** URL of the <code>AGSGPResultLayer</code> resource in the ArcGIS Server REST 
 Services Directory.
 @since 1.0
 */
@property (nonatomic, copy, readonly) NSURL *URL;

/** The credential to be used to access secured resources.
 @since 1.0
 */
@property (nonatomic, copy, readwrite) AGSCredential *credential;

/** The credential cache to be used for this resource. By default this will be set to the global cache.
 @since 10.1.1
 */
@property (nonatomic, strong, readwrite) AGSCredentialCache *credentialCache;

/** The DPI (dots-per-inch) resolution of map images generated by this layer's map service.
 The dpi will default to a value that takes into account the dpi of the device and the value of the
 renderNativeResolution property. If you programmatically change the dpi, it will then cease
 to change when the renderNativeResolution property changes.
 @since 1.0
 */
@property (nonatomic) NSUInteger dpi;

/** The image format of the map. Possible values include
 
 @li @c AGSImageFormatPNG32
 @li @c AGSImageFormatPNG24
 @li @c AGSImageFormatPNG8
 @li @c AGSImageFormatPNG
 @li @c AGSImageFormatJPG
 @li @c AGSImageFormatGIF 
 
 Please consult the ArcGIS Server REST Services Directory to ensure the map service 
 supports the requested image format.
 
 @since 1.0
 */
@property (nonatomic) AGSImageFormat imageFormat;

/** A property indicating whether or not images generated by the map service 
 should be transparent.
 @since 1.0
 */
@property (nonatomic) BOOL transparent;

/** Flag indicating if the layer renders at the native resolution. 
 This property will not have any affect iOS devices without a retina display. If using an iOS
 device with a retina display and you want to take advantage of that display you can set
 this value to YES. The property must be set before the layer loads.
 
 When rendering at the native resolution, this layer will use more network bandwidth and memory (because the map images will be bigger).
 @since 2.1
 */
@property (nonatomic, assign, readwrite) BOOL renderNativeResolution;

/** Initialize this layer with a URL of a <code>AGSGPResultLayer</code>
 @param url to dynamic map service.
 @return A new <code>%AGSGPResultLayer</code> object.
 @since 1.0
 */
- (id)initWithURL:(NSURL *)url;

/** Initialize this layer with a URL of a <code>AGSGPResultLayer</code>
 @param url to dynamic map service. 
 @param cred @c AGSCredential to use to access secured resource.  
 @return A new <code>%AGSGPResultLayer</code> object.
 @since 1.0
 */
- (id)initWithURL:(NSURL *)url credential:(AGSCredential*)cred;


@end
